msg = {
    "-3" : "send mail exception",
    "-2" : "Request parameter exception",
    "-1" : "Service Error",

    "1000" : "User already exists",
    "1001" : "This user does not exist",
    "1002" : "Incorrect account password",
    "1003" : "Internal error",
    "1004" : "Authorization failed",
    "1005" : "User is not activated",
    "1006" : "User activated",
    "1007" : "Incorrect activation code",
    "1008" : "Password format is composed of 8-126 alphanumeric special characters",
    "1009" : "User information does not exist",
    "1010" : "Same username",
    "1020" : "The user has been authenticated with real name, and it is not allowed to modify the name and ID number",
    "1021" : "wrong identification number",
    "1022" : "Name must be in Chinese",
    "1023" : "The phone number is the same as the old phone number",
    "1024" : "Phone number format is not correct",
    "1025" : "The alternate email format is incorrect",
    "1026" : "User status error",
    "1027" : "The two passwords entered are not consistent",
    "1028" : "During real-name authentication, you cannot submit again",
    "1029" : "The front photo of the ID card does not exist",
    "1030" : "Verification code has expired",
    "1031" : "Picture format can only be jpg, jpeg, png",
    "1032" : "Alternate mailbox and mailbox duplicate",
    "1033" : "The start time is less than the end time",
    "1034" : "sortDate and sortCost cannot be sorted at the same time",
    "1035" : "User wallet does not exist",
    "1036" : "User nickname already exists",
    "1037" : "User disabled",
    "1038" : "User enabled",
    "1039" : "Insufficient user balance",
    "1040" : "User nickname cannot be mailbox",
    "1041" : "The photo on the back of the ID card does not exist",

    "1100" : "Wrong recharge type",
    "1101" : "Order does not exist",

    "1300" : "STS authorization failed",
    "1301" : "Internal method verification failed",

    "2000" : "User already exists",
    "2001" : "Authorization failed",
    "2002" : "Failed to request SSO service",
    "2003" : "STS authorization failed",
    "2004" : "The user already exists registration failed",
    "2005" : "User does not exist",
    "2006" : "Forbidden error",
    "2007" : "Insufficient balance, unable to operate, please recharge",
    "2008" : "Deactivation failed, please exit all projects first",
    "2009" : "Internal method verification failed",

    "2100" : "Project name already exists",
    "2101" : "Project does not exist",
    "2102" : "User is already in the project",
    "2103" : "The role does not exist in the project",
    "2104" : "The user was not found in the project",
    "2105" : "Only the owner has the right to modify permissions",
    "2106" : "Cannot modify the permissions of the project owner",

    "2200" : "Directory does not exist",
    "2201" : "File does not exist",
    "2202" : "Duplicate file id",
    "2203" : "Duplicate file name",
    "2204" : "Operation file attribution error",
    "2205" : "File upload error",
    "2206" : "Cannot move to the original directory",
    "2207" : "The file name format is wrong, the file name needs a suffix",
    "2208" : "Cannot move to the output directory",
    "2209" : "Cannot create a folder in the output directory",
    "2210" : "Files in the output directory cannot be renamed",
    "2211" : "File name/directory name is invalid",
    "2212" : "A file with the same name already exists",
    "2213" : "A directory with the same name already exists",
    "2214" : "Cannot move to the store directory",
    "2215" : "Files in the store directory cannot be renamed",
    "2216" : "Cannot be copied to the output directory",
    "2217" : "Cannot be copied to the store directory",
    "2218" : "Cannot copy the store directory and the files in it",
    "2219" : "Cannot be copied to the same folder",
    "2220" : "The directory already has a file or folder with the same name",


    "2300" : "Command parameters cannot use wildcards",
    "2301" : "Input file key does not match",
    "2302" : "Output file key does not match",
    "2303" : "OutName error",
    "2304" : "Duplicate input key",
    "2305" : "Tool does not exist",
    "2306" : "Tool file cannot be empty",
    "2307" : "Tool label cannot be repeated",
    "2308" : "Incorrect tool name",
    "2309" : "Tool is missing output file",
    "2310" : "Tool already exists, do not create it again",
    "2311" : "You cannot delete a tool version with only one version",
    "2312" : "The tool version does not exist",
    "2313" : "Tool input file label cannot be repeated",
    "2314" : "The label of the tool output file cannot be repeated",
    "2315" : "Duplicate output key",
    "2316" : "cmd number type value is wrong",


    "2400" : "The flow with the same name already exists",
    "2401" : "The flow node does not exist",
    "2402" : "The flow does not exist",
    "2403" : "The flow is being referenced",
    "2404" : "The flow version is being referenced",
    "2405" : "The flow version does not exist",
    "2406" : "At least one final output file is required in the flow",
    "2407" : "Duplicate flow reference parent node",
    "2408" : "Flow reference error",
    "2409" : "Please set the final output file in the flow leaf node",
    "2410" : "Duplicate node names are not allowed in the flow",
    "2411" : "Flow loop error",
    "2412" : "There is a disconnection error in the flow",


    "2500" : "Duplicate node names are not allowed in the job",
    "2501" : "Please set the final output file in the job leaf node",
    "2502" : "Duplicate job reference parent node",
    "2503" : "Job reference error",
    "2504" : "Job loop error",
    "2505" : "There is a disconnection error in the job",
    "2506" : "Job does not exist",
    "2507" : "The job is running and cannot be deleted",
    "2508" : "Duplicate output folder",
    "2509" : "Wrong output folder path",
    "2510" : "Stop error, job succeeded",
    "2511" : "Stop error, job has failed",
    "2512" : "Stop error, job has stopped",


    "2600" : "Resource pack does not exist",
    "2601" : "Duplicate resource pack name",
    "2602" : "Duplicate resource pack payment method",
    "2603" : "Update resource package name error",
    "2604" : "Resource pack price error",
    "2605" : "Cannot subscribe to self-published mall packages",
    "2606" : "Tag already exists",
    "2607" : "Can't repeat likes",
    "2608" : "Cancel like error",
    "2609" : "Resource package deduction method does not exist",
    "2610" : "Resource pack already has a tag with the same name",
    "2611" : "This label does not exist in the resource pack",
    "2612" : "This operation cannot be performed on the resource pack label",

    "2621" : "No permission to upload the file",
    "2622" : "No permission to upload the tool",
    "2623" : "No permission to upload the flow",

    "2641" : "Duplicate upload file",
    "2642" : "Duplicate upload tool",
    "2643" : "Duplicate upload flow",

    "2661" : "The resource pack is already subscribed",
    "2662" : "The resource subscription package does not exist",
    "2663" : "Resource subscription package cannot be imported repeatedly",
    "2664" : "Resource subscription directory does not exist",
    "2665" : "The flow does not belong to the user",
    "2666" : "Cannot update this resource subscription package",

    "2681" : "Subscription package added to project duplicate error",
    "2682" : "No permission to import into the project",
    "2683" : "You cannot import the same subscription package repeatedly into the same project",
    "2684" : "Resource pack is not added to the project",
    "2685" : "Resource is locked, import cannot be canceled",
    "2686" : "This operation cannot be performed on imported resources",

    "2700" : "Message does not exist",
    "2701" : "The message cannot be repeated to set the read status",
    "2702" : "Non-deletable announcement",
    "2703" : "Can only delete own messages",

    "2800" : "The problem does not exist",
    "2801" : "No permission to delete this question",
    "2802" : "The problem does not exist",
    "2803" : "No permission to delete this label",

    "2900": "The final output file name is wrong",
    "2901": "Cmd format error",
    "2902": "Duplicate cmd key",
    "2903": "Operational resources are locked",
    "2904": "File key does not match cmd key",
    "2905": "Worker node type does not exist",
    "2906": "Oss file reference error",
    "2907": "Worker type not selected",
    "2908": "Wrong Worker type selection",
    "2909": "The number of references for this resource is zero",
    "2910": "Text conversion error",
    "2911": "Input file list error",
    "2912": "Output file list error",
    "2913": "CMD does not match the parameter"
  }